// **************************************************************************************
// el Comandante                                                    guerilla.bplaced.net
// --------------------------------------------------------------------------------------
// Information:
// Breakout Board with LED's, I2C Interface, I/O Expander PCF8574, 3-Wire (SDA, SCL, !RES)
// There are different types of the PCF8574 available, with different I2C address ranges
// The I2C slave address range for the PCF8574    is 0x20 - 0x27
// The I2C slave address range for the PCF8574AN  is 0x38 - 0x3F
// --------------------------------------------------------------------------------------
// Libraries:
// PCF8574  --> https://github.com/RobTillaart/PCF8574.git
// --------------------------------------------------------------------------------------
// Documentations:
// Overview ESP32 mcu's   - https://socialcompare.com/en/comparison/esp8266-vs-esp32-vs-esp32-s2
// Espressif ESP32 docu's - https://www.espressif.com/en/support/documents/technical-documents
// --------------------------------------------------------------------------------------
// Device WT32-SC01       - http://myosuploads3.banggood.com/products/20220111/20220111020446WT32-SC01DataSheetV3.3.pdf
// TFT Device ST7796      - https://cdn.hackaday.io/files/1625926956336128/ST7796S.pdf
// Touch Device FT6336U   - https://focuslcds.com/content/FT6236.pdf
// --------------------------------------------------------------------------------------
// Device TTGO-T-Display  - https://github.com/Xinyuan-LilyGO/TTGO-T-Display
// TFT Device ST7789V     - https://newhavendisplay.com/content/datasheets/ST7789V.pdf
// **************************************************************************************
#include <Wire.h>                                         // Arduino Wire library
#include <PCF8574.h>                                      // PCF8574 library

// ######################################################################################
// Change values in this area to match your envoirement and desires
// --------------------------------------------------------------------------------------
// I2C pins, i.e. WT32-SC01 (SDA 18,SCL 19,!RES 25), TTGO T Display (SDA 21,SCL 22,!RES 25)
#define         SDA 18                                    // I2C interface
#define         SCL 19                                    // I2C interface
#define         RES 25                                    // !Reset signal
#define         I2C_ADR 0x3F                              // I2C address (A0, A1, A2)
#define         Speed 1000                                // Speed next LED on
// ######################################################################################

// Vars
uint8_t         i;                                        // index var

//  I2C address
PCF8574 PCF_3F(I2C_ADR);                                  // I2C address

// **************************************************************************************
// Setup
// **************************************************************************************
void setup()
{
  Serial.begin(115200);
  delay (1000);

  Wire.begin(SDA, SCL);                                   // i2c - init
  delay (1000);

  PCF_3F.begin();

  PCF_3F.write8(255);                                     // all LEDs switched OFF
  delay(2000);
  PCF_3F.write8(0);                                       // all LEDs switched ON
  delay(2000);
  PCF_3F.write8(255);                                     // all LEDs switched OFF
}

// **************************************************************************************
// Main Loop
// **************************************************************************************
void loop()
{
  PCF_3F.write8(255);                                     // all LEDs switched OFF
  delay(2000);
  for(i = 0; i < 8; i++)                                  // LEDs 1-8 Port A, switched on
  {
    PCF_3F.write(i, LOW);                                 // LED i switched ON
    delay(Speed);
    PCF_3F.write(i, HIGH);                                // LED i switched OFF
    delay(Speed);
  }
}
